function cie_chart()
%function cie_chart()
% Plots and labels the CIE chromaticity diagram, the sRGB gamut triangle, and the blackbody temperature locus.
% primaries and white point data from: qtmonitorprofilerdialog.cpp
%%%%%%%%%%%%%%%%%%%%%     Chromaticity Space diagram     %%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. chromaticity space diagram
% 2. sample colorspace gamut triangle plot (sRGB )
% 3. common illuminants' white points (D65, ill.-A, etc.)
% 4. blackbody temperature locus (in degrees Kelvin)

% Plot the Chromaticity Space diagram ("tongue" or "horseshoe" shaped).
figure;
h=gcf;
get(h);
set(h,'PaperSize',[11 11]);
cie=CIE1931_2d;
plot(cie(:,2),cie(:,3),'b-');
hold;
plot(cie(1:5:471,2),cie(1:5:471,3),'b.');
line([cie(1,2) cie(471,2)],[ cie(1,3) cie(471,3)],'Color','b');
title('CIE 1931 2-degree Chromaticity Chart');
hold;
qwe(1:471)=' ';
qwe=qwe';
cie_colour_match=ColorMatch1931; % ( 474x4)
% chromaticity values for lambda <450 and >650 will not plot well on the diagram.
% Plot the text labels for the spectrum in 5nm steps
text(cie(101:5:251,2), cie(101:5:251,3), [ qwe(101:5:251,1) qwe(101:5:251,1) num2str(cie(101:5:251,1)) ] ,'FontSize',8);
xlabel('x-chromaticity');
ylabel('y-chromaticity');
legend('Chromaticity');
%%%%%%%%%%%%%%%%%%  Color Space primaries plots  (sRGB) %%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the sRGB colorspace gamut triangle
% These numbers can be extracted from icc profiles.
%---------------------  sRGB  --------------------------
hold on;
plot(0.640, 0.330,'g.'); 
plot(0.300, 0.600 ,'g.');
plot(0.150, 0.060,'g.');
sRGB=[0.640, 0.330, 0.300, 0.600, 0.150, 0.060 ];
line([sRGB(1) sRGB(3)],[sRGB(2),sRGB(4)],'Color','r');
line([sRGB(5) sRGB(1)],[sRGB(6),sRGB(2)],'Color','r');
line([sRGB(3) sRGB(5)],[sRGB(4),sRGB(6)],'Color','r');
text(.15,.6,'sRGB gamut','Color','r'); % Hand-positioned through trial and error.

%%%%%%%%%%%%%%%% Plot the common illuminant white points %%%%%%%%%%%%%%%%%%%%%%%%%		
%name x, y, temperature (K)
D50= [0.3457, 0.3585, 5000];
D55= [0.3324, 0.3474, 5500];
D65= [0.3127, 0.3291, 6500];
D75= [0.2990, 0.3149, 7500 ];
D93 = [0.2848, 0.2932, 9300 ];
A= [0.4476 0.4074 0];
B= [0.34842 0.35161 0];
C= [0.3101 0.3162 0];
E= [0.3333 0.3333 0]; % WardTrueWhite=[0.3333 0.3333 0];
UserDefined= [0 0 0];% (blackbody locus)

plot(A(1),A(2),'r.');
plot(B(1),B(2),'r.');
plot(C(1),C(2),'r.');
plot(E(1),E(2),'r.');

plot(D50(1),D50(2),'b.');
plot(D55(1),D55(2),'b.');
plot(D65(1),D65(2),'b.');
plot(D75(1),D75(2),'b.');
plot(D93(1),D93(2),'b.');

text(A(1),A(2)-.03,' A','FontSize',7);
text(B(1),B(2)-.03,' B','FontSize',7);  
text(C(1),C(2)-.03,' C','FontSize',7);

text(D50(1)-.02,D50(2)+.04,' D50','FontSize',7);
text(D55(1)-.03,D55(2)+.04,' D55','FontSize',7);
text(D65(1)-.04,D65(2)+.04,' D65','FontSize',7);
text(D75(1)-.05,D75(2)+.03,' D75','FontSize',7);
text(D93(1)-.06,D93(2)+.02,' D93','FontSize',7);

hold on;
%%%%%%%%%%%%%%%%%%%%%%     Blackbody Locus Plot    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% blackbody prep  ===========================
lambda=360:830;
C1 = 5.9634e-17;
C2 = 1.4387e-2;
C1b = 3.74183e-16 ;
k = 8.617e-5;		%{ Boltzmann constant (eV/K) }
h = 4.136e-15;	%	{ Plank constant (eV-sec) }
e = 1.602e-19;	%	{ elemetary charge (Coulombs) }
c = 2.998e8;		%{ speed of light (m/sec) }
PI= 3.14159;
X=0;Y=0;Z=0;
Xmvt=0;Ymvt=0;Zmvt=0;
xbmvt(1:291)=0;ybmvt(1:291)=0;
lam = lambda(:)'*1e-9;
% Plot the MVT(Machine Vision Toolbox) version of the blackbody locus.
for T=1000:100:30000,
	for  ix = 1:471,
		%e = 2 .* C1  ./ (lam(ix) .^ 5 .* (exp(C2 ./ T ./ lam(ix)) - 1));
		e = C1b .* ((lam(ix)  .^ -5) ./ exp(C2 ./ (lam(ix) .* T)) - 1 )  ;
		Xmvt = Xmvt + (e .* cie_colour_match(ix,2)); 
		Ymvt = Ymvt + (e .* cie_colour_match(ix,3));
		Zmvt = Zmvt + (e .* cie_colour_match(ix,4));
	end
	xbmvt(T/100) = Xmvt / (Xmvt + Ymvt + Zmvt);
	ybmvt(T/100) = Ymvt / (Xmvt + Ymvt + Zmvt);
end
plot(xbmvt(10:300),ybmvt(10:300),'r-');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Print the finished diagram
print -djpeg 'Chromaticity_chart(sRGB).jpg';
	
%  WideGamut=[ 0.7347,0.2653,0.1152,0.8264,0.1566,0.0177]; % RGB  700/525/450 nm
%  text(E(1 ),E(2)-.05,' E');CIE=[0.7355,0.2645,0.2658,0.7243,0.1669,0.0085];
%  HDTV=[0.670, 0.330, 0.210, 0.710, 0.150, 0.060 ];
%  Ward_NominalCRT=[0.640,0.330,0.290,0.600,0.150,0.060];
%  SMPTE1994=[0.64,  0.33,  0.29,  0.60,  0.15,  0.06 ];
%  SMPTE601=[0.630, 0.340, 0.310, 0.595, 0.155, 0.070];
%  EBU3213_E=[0.630, 0.340, 0.310, 0.595, 0.155, 0.070 ];
%  EBU_Walker98=[	0.64,  0.33,  0.30,  0.60,  0.15,  0.06 ];
%  P22=[	0.625, 0.340, 0.280, 0.595, 0.155, 0.070];
%  NTSC=[0.67,  0.33,  0.21,  0.71,  0.14,  0.08 ];
%  Dell=[0.625, 0.340, 0.275, 0.605, 0.150, 0.065];
%  LCD=[0.700, 0.300, 0.170, 0.700, 0.130, 0.075];
%  SamsungTFT=[0.610, 0.350, 0.315, 0.580, 0.150, 0.140];
%  Apple_RGB=[0.625, 0.34,  0.28,  0.595, 0.155, 0.07 ];
%  ShortPersFoley96=[0.61,  0.35,  0.29,  0.59,  0.15,  0.063];
%  LongPersFoley96=[0.62,  0.33,  0.21,  0.685, 0.15,  0.063];
%  AdobeRGB=[0.64,  0.33,  0.21,  0.71,  0.15,  0.06 ];
%  UserDefined=[0.640, 0.330, 0.300, 0.600, 0.150, 0.060 ];
%  
% 
% Chromaticity :
%  	x = X / ( X + Y+ Z ) 
%  	y = Y / ( X + Y+ Z ) 
%  	z = Z / ( X + Y+ Z )
%  	x + y + z = 1
%  	z = 1 - x - y
%  	X = (Y / y) * x 
%  	Z = (Y / y) * ( 1 - x - y ) = (Y / y) * z 
%
